HPD <- function( postSampleVec , credMass=0.95 ) {
    # function obtained from J. Kruschke (2011). Doing Bayesian Analysis. Elsevier Academic Press, Burlington, MA. 
	
	# Estimates credible intervals from a sample of representative values.
    #   Yields only single-segment credible intervals (effectively assumes that
    #   the density is unimodal).

    #eqTailLim = quantile( postSampleVec ,
    #                      probs=c( (1-credMass)/2 , 1-(1-credMass)/2 ) )

    # Estimate HPD interval by finding shortest credible interval:
    sortedpts = sort( postSampleVec )
    ciIdxInc = floor( credMass * length( sortedpts ) )
    nCIs = length( sortedpts ) - ciIdxInc
    ciWidth = rep( 0 , nCIs )
    for ( i in 1:nCIs ) {
        ciWidth[ i ] = sortedpts[ i + ciIdxInc ] - sortedpts[ i ]
    }
    HPDmin = sortedpts[ which.min( ciWidth ) ]
    HPDmax = sortedpts[ which.min( ciWidth ) + ciIdxInc ]
    HPDlim = c( HPDmin , HPDmax )
    return(hpd = HPDlim )
}
